@@ -12,8 +12,23 @@ import pyfilesec
 from   pyfilesec import *
 from   pyfilesec import _abspath, _uniq_file, _parse_args
 
-from test_crypto import _known_values
+def _known_values(folder='.'):
+    """Return tmp files with known keys, data, signature for testing.
+    This is a WEAK key, 1024 bits, for testing ONLY.
+    """
+    bits = '1024'
+    pub, priv, pphr = GenRSA().demo_rsa_keys(folder)
 
+    kwnSig0p9p8 = (  # openssl 0.9.8r
+        "dNF9IudjTjZ9sxO5P07Kal9FkY7hCRJCyn7IbebJtcEoVOpuU5Gs9pSngPnDvFE"
+        "2BILvwRFCGq30Ehnhm8USZ1zc5m2nw6S97LFPNFepnB6h+575OHfHX6Eaothpcz"
+        "BK+91UMVId13iTu9d1HaGgHriK6BcasSuN0iTfvbvnGc4=")
+    kwnSig1p0 = (   # openssl 1.0.1e or 1.0.0-fips
+        "eWv7oIGw9hnWgSmicFxakPOsxGMeEh8Dxf/HlqP0aSX+qJ8+whMeJ3Ol7AgjsrN"
+        "mfk//J4mywjLeBp5ny5BBd15mDeaOLn1ETmkiXePhomQiGAaynfyQfEOw/F6/Ux"
+        "03rlYerys2Cktgpya8ezxbOwJcOCnHKydnf1xkGDdFywc=")
+    return (_abspath(pub), _abspath(priv), _abspath(pphr),
+            bits, (kwnSig0p9p8, kwnSig1p0))
 
 class TestBasics(object):
     """Test suite for noncrypto.
@@ -38,6 +53,7 @@ class TestBasics(object):
         os.chdir(self.start_dir)
         shutil.rmtree(self.tmp, ignore_errors=True)
 
+    '''
     def test_SecStr_printable_pwd(self):
         # ensure a non-interned string because has '#'
         s = '#ca6e89'
@@ -81,17 +97,12 @@ class TestBasics(object):
         assert pwd.__repr__()
         assert pwd._id == None
         assert pwd._val == pwd.str == b'\0' * (256 // 4 + 1)
+    '''
 
     @pytest.mark.notravis
     def test_import_pyperclip(self):
         import _pyperclip
 
-    def test_constants_imports(self):
-        import pyfilesec.constants
-        os.chdir(self.start_dir)
-        import which
-        os.chdir(self.tmp)
-
     def test_import_getpass_which(self):
         os.chdir(self.start_dir)
         import _getpass
@@ -100,7 +111,7 @@ class TestBasics(object):
 
     def test_SecFileBase(self):
         test_file = 'tf'
-        with open(test_file, 'wb') as fd:
+        with open(test_file, write_mode) as fd:
             fd.write('a')
         sf = SecFile(test_file)  # inherits from _SecFileBase
         sf.openssl = OPENSSL
@@ -151,7 +162,7 @@ class TestBasics(object):
         no_write = 'non_writeable_test'
         os.makedirs(no_write)
         f = os.path.join(no_write, 'tmp_no_write')
-        with open(f, 'wb') as fd:
+        with open(f, write_mode) as fd:
             fd.write('x')
         sf = SecFile(f)
         assert sf.is_in_writeable_dir
@@ -361,29 +372,46 @@ class TestBasics(object):
             sf.encrypt(pub1, meta='junk', keep=True)
 
     def test_max_size_limit(self):
-        # manual test: works with an actual 1G (MAX_FILE_SIZE) file as well
+        # avoid large files at encrypt() or pad(), others ok
+        # manually tested: works with an actual large file as well
         MAX_restore = pyfilesec.MAX_FILE_SIZE
         pyfilesec.MAX_FILE_SIZE = 2 ** 8  # fake, to test if hit the limit
-        tmpmax = 'maxsize.txt'
-        with open(tmpmax, 'w+b') as fd:
+        over_max = 'maxsize_plus1.txt'
+        with open(over_max, write_mode) as fd:
             fd.write(b'a' * (pyfilesec.MAX_FILE_SIZE + 1))  # ensure too large
 
-        with pytest.raises(FileStatusError):
-            sf = SecFile(tmpmax)
+        # test whether invoking encrypt/decrypt checks file size appropriately:
+        pub, priv, pphr = _known_values()[:3]
+
+        # no error to set a large file--might be an encrypted file:
+        sf = SecFile(over_max)
+        # yes error if try to encrypt it:
+        with pytest.raises(ValueError):
+            sf.encrypt(pub)
+
+        # yes ValueError if try to pad it: (PaddingError if just under max)
         pyfilesec.MAX_FILE_SIZE += 2
-        sf = SecFile(tmpmax)
+        sf = SecFile(over_max)
         with pytest.raises(ValueError):
             sf.pad(pyfilesec.MAX_FILE_SIZE + 1)
-        pyfilesec.MAX_FILE_SIZE = getsize(tmpmax) - 2
-        with pytest.raises(ValueError):
-            hmac_sha256('key', tmpmax)
+
+        # a file that goes over max size duing encryption should still decrypt:
+        at_max = 'maxsize.txt'
+        msg = b'a' * (pyfilesec.MAX_FILE_SIZE)
+        with open(at_max, write_mode) as fd:
+            fd.write(msg)
+        sf = SecFile(at_max)
+        sf.encrypt(pub)
+        assert sf.size > pyfilesec.MAX_FILE_SIZE
+        sf.decrypt(priv, pphr=pphr)
+        assert open(sf.file, read_mode).read() == msg
 
         pyfilesec.MAX_FILE_SIZE = MAX_restore
 
     def test_compressability(self):
         # idea: check that encrypted is not compressable, cleartext is
         datafile = 'test_size'
-        with open(datafile, 'wb') as fd:
+        with open(datafile, write_mode) as fd:
             fd.write(b'1')
         size_orig = getsize(datafile)
         assert size_orig == 1
@@ -412,7 +440,7 @@ class TestBasics(object):
         filename = 'umask_test no unicode'
         pub, priv, pphr = _known_values()[:3]
         umask_restore = os.umask(0o002)  # need permissive to test
-        with open(filename, 'wb') as fd:
+        with open(filename, write_mode) as fd:
             fd.write(b'\0')
         assert permissions_str(filename) == '0o664'  # permissive to test
         sf = SecFile(filename)
